Index: wp-includes/category-template.php
===================================================================
--- wp-includes/category-template.php	(revision 21117)
+++ wp-includes/category-template.php	(working copy)
@@ -379,8 +379,27 @@
 }
 
 /**
  * Display or retrieve the HTML list of categories.
  *
+ * The list of arguments matches wp_dropdown_categories() with the exception of
+ * 'taxonomy', which is it's own function argument here.
+ *
+ * @since 3.5
+ *
+ * @param string $taxonomy Taxonomy name
+ * @param string|array $args Optional. Override default arguments.
+ * @return string HTML content only if 'echo' argument is 0.
+ */
+function wp_dropdown_terms( $taxonomy, $args = '' ) {
+	$args = wp_parse_args( $args );
+	$args['taxonomy'] = $taxonomy;
+
+	return wp_dropdown_categories( $args );
+}
+
+/**
+ * Display or retrieve the HTML list of a taxonomy's terms.
+ *
  * The list of arguments is below:
  *     'show_option_all' (string) - Text to display for showing all categories.
  *     'orderby' (string) default is 'ID' - What column to use for ordering the
@@ -491,6 +510,25 @@
 }
 
 /**
+ * Display or retrieve the HTML list of a taxonomy's terms.
+ *
+ * The list of arguments matches wp_list_categories() with the exception of
+ * 'taxonomy', which is it's own function argument here.
+ *
+ * @since 3.5
+ *
+ * @param string $taxonomy Taxonomy name
+ * @param string|array $args Optional. Override default arguments.
+ * @return string HTML content only if 'echo' argument is 0.
+ */
+function wp_list_terms( $taxonomy, $args = '' ) {
+	$args = wp_parse_args( $args );
+	$args['taxonomy'] = $taxonomy;
+
+	return wp_list_categories( $args );
+}
+
+/**
  * Display tag cloud.
  *
  * The text size is set by the 'smallest' and 'largest' arguments, which will
@@ -379,8 +379,27 @@
 
 /**
- * Display or retrieve the HTML list of categories.
+ * Display or retrieve the HTML dropdown list of terms.
  *
